==> dl.php?src=linea21_2_5_0.zip: linea21/user/sup.php <==
<?php
/**
 * User module
 * 
 * Delete given user from back-office
 * 
 * @package linea21\core\user
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id;

$requete= SQL_getUserLogin($id);
$result=$sql_object->DBSelect($requete);


// Do record exists?
if(!isset($result[0]['user_login'])) redirect_to('@module_default');

$current_title=stripslashes($result[0]['user_login']);


if(isset($_POST['valider'])) {
  $user_object = new user;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
  $result=$user_object->DeleteUser($id, $sql_object);
  $user_object->deleteAvatar($id, $sql_object);
  
  if(isset($_POST['make-ano'])) {
      do {
          $newlogin = _t('user', 'anonymous_suffix') . '_' . generateRandomString(4, '0123456789');
      } while (false);
      
      $user_object->changeLogin($id, $newlogin, $current_title, $sql_object);
  }
  
  if($result) {
      header("Location: ".safe_redirect($link_confirm));
      exit;
  }
  else  system_error();
}




if($result[0]['user_password'] == '@ldap_forward') {
	$suffix= '<i class="icon-universal-access"></i>';
} else {
	$suffix= ' ';
}

?>
<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home') ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','user')?></a></li>
	<li><span><?php echo formatnavTitle(_t('user','sup')." : ". $current_title); ?></span></li>
</ul>
</div>
<!--end barre haute -->

<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php echo "<h2>".formatTitleh2($current_title).$suffix. "</h2>"; ?>
<form id="supuser" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
		<p class="info"><i class="icon-trash"></i> <?php echo _t('divers','sup_confirm'); ?></p>
		<div>
		<div class="mts">
        	<div class="label" title="<?php echo mb_ucfirst(_t('user','make-anonymous')); ?>"><?php echo mb_ucfirst(_t('user','make-anonymous')); ?> :</div>
        	<div class="rightpanel">
        		<input type="checkbox" class="checkbox-switch" name="make-ano" id="make-ano" value="1" checked />
        		<label for="make-ano" title="<?php echo mb_ucfirst(_t('user','make-anonymous')); ?>"></label>
        	</div>
        </div>
		<input name="id" type="hidden" value="<?php echo $id; ?>" />
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<?php echo cancel_button('javascript:history.go(-1);'); ?>
		<input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
	</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->

==> dl.php?src=linea21_2_8_0.zip: linea21/user/sup.php <==
<?php
/**
 * User module
 * 
 * Delete given user from back-office
 * 
 * @package linea21\core\user
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];
$link_det=$rub_link."&amp;todo=det&amp;id=".$id;

$requete= SQL_getUserLogin($id);
$result=$sql_object->DBSelect($requete);


// Do record exists?
if(!isset($result[0]['user_login'])) redirect_to('@module_default');

$current_title=stripslashes($result[0]['user_login']);


if(isset($_POST['valider'])) {
  $user_object = new user;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
  $result=$user_object->DeleteUser($id, $sql_object);
  $user_object->deleteAvatar($id, $sql_object);
  
  if(isset($_POST['make-ano'])) {
      do {
          $newlogin = _t('user', 'anonymous_suffix') . '_' . generateRandomString(4, '0123456789');
      } while (false);
      
      $user_object->changeLogin($id, $newlogin, $current_title, $sql_object);
  }
  
  if($result) {
      header("Location: ".safe_redirect($link_confirm));
      exit;
  }
  else  system_error();
}




if($result[0]['user_password'] == '@ldap_forward') {
	$suffix= ' <i class="fa fa-universal-access" aria-hidden="true"></i></i>';
} else {
	$suffix= ' ';
}

?>
<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home') ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','user')?></a></li>
	<li><span><?php echo formatnavTitle(_t('user','sup')." : ". $current_title); ?></span></li>
</ul>
</div>
<!--end barre haute -->

<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php echo "<h2>".formatTitleh2($current_title).$suffix. "</h2>"; ?>
<form id="supuser" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
		<p class="info"><i class="fa fa-trash"></i> <?php echo _t('divers','sup_confirm'); ?></p>
		<div>
		<p class="mts">
        	<label for="make-ano"><?php echo mb_ucfirst(_t('user','make-anonymous')); ?> :</label>
        	<input type="checkbox" class="switch" name="make-ano" id="make-ano" value="1" checked />
        </p>
		<input name="id" type="hidden" value="<?php echo $id; ?>" />
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<?php echo cancel_button('javascript:history.go(-1);'); ?>
		<input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
	</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
